@@ -77,3 +77,18 @@ class CDNTests(utils.TestCase):
         self.assertIsInstance(refs, tuple)
         if refs:
             self.assertIsInstance(refs[1], dict)
+
+    def test_prefetch(self):
+        urls = [
+            'http://downcdn.ptsuyou.com/img/index/zhinengyun.png',
+            'http://downcdn.ptsuyou.com/js/jquery-1.8.0.min.js'
+        ]
+        refs = self.client.cdn.prefetch(urls)
+        print refs
+        self.assertIsInstance(refs, cdn.CDN)
+
+    def test_prefetch_query(self):
+        request_id = '351eaa97-56a9-43ce-9e24-7a78bea310daa'
+        refs = self.client.cdn.prefetch_query(request_id)
+        print refs
+        self.assertIsInstance(refs, cdn.CDN)
